@@ -4,19 +4,14 @@ import {
   ILayoutRestorer
 } from '@jupyterlab/application';
 
-import {
-  IWidgetTracker,
-  ReactWidget,
-  IThemeManager
-} from '@jupyterlab/apputils';
+import { IWidgetTracker, ReactWidget } from '@jupyterlab/apputils';
 import { IDocumentWidget } from '@jupyterlab/docregistry';
-import { IGlobalAwareness } from '@jupyterlab/collaboration';
+import { IGlobalAwareness } from '@jupyter/collaboration';
 import type { Awareness } from 'y-protocols/awareness';
 import { buildChatSidebar } from './widgets/chat-sidebar';
 import { SelectionWatcher } from './selection-watcher';
 import { ChatHandler } from './chat_handler';
 import { buildErrorWidget } from './widgets/chat-error';
-import { IRenderMimeRegistry } from '@jupyterlab/rendermime';
 
 export type DocumentTracker = IWidgetTracker<IDocumentWidget>;
 
@@ -26,14 +21,11 @@ export type DocumentTracker = IWidgetTracker<IDocumentWidget>;
 const plugin: JupyterFrontEndPlugin<void> = {
   id: 'jupyter_ai:plugin',
   autoStart: true,
-  optional: [IGlobalAwareness, ILayoutRestorer, IThemeManager],
-  requires: [IRenderMimeRegistry],
+  optional: [IGlobalAwareness, ILayoutRestorer],
   activate: async (
     app: JupyterFrontEnd,
-    rmRegistry: IRenderMimeRegistry,
     globalAwareness: Awareness | null,
-    restorer: ILayoutRestorer | null,
-    themeManager: IThemeManager | null
+    restorer: ILayoutRestorer | null
   ) => {
     /**
      * Initialize selection watcher singleton
@@ -51,12 +43,10 @@ const plugin: JupyterFrontEndPlugin<void> = {
       chatWidget = buildChatSidebar(
         selectionWatcher,
         chatHandler,
-        globalAwareness,
-        themeManager,
-        rmRegistry
+        globalAwareness
       );
     } catch (e) {
-      chatWidget = buildErrorWidget(themeManager);
+      chatWidget = buildErrorWidget();
     }
 
     /**
