@@ -26,8 +26,10 @@ export function getTextSelection(widget: Widget): string {
 /**
  * Get editor instance from an editor widget (i.e. `DocumentWidget#content`).
  */
-export function getEditor(widget: Widget): CodeEditor.IEditor | undefined {
-  let editor: CodeEditor.IEditor | undefined;
+export function getEditor(
+  widget: Widget
+): CodeEditor.IEditor | null | undefined {
+  let editor: CodeEditor.IEditor | null | undefined;
   if (widget instanceof FileEditor) {
     editor = widget.editor;
   } else if (widget instanceof Notebook) {
@@ -46,26 +48,3 @@ export function getCellIndex(notebook: Notebook, cellId: string): number {
   );
   return idx === undefined ? -1 : idx;
 }
-
-/**
- * Obtain the provider ID component from a model ID.
- */
-export function getProviderId(globalModelId: string): string | null {
-  if (!globalModelId) {
-    return null;
-  }
-
-  return globalModelId.split(':')[0];
-}
-
-/**
- * Obtain the model name component from a model ID.
- */
-export function getModelLocalId(globalModelId: string): string | null {
-  if (!globalModelId) {
-    return null;
-  }
-
-  const components = globalModelId.split(':').slice(1);
-  return components.join(':');
-}
